from lektor.pluginsystem import Plugin
from lektor.markdown import Markdown


class MarkdownExcerptPlugin(Plugin):
    name = u'Markdown Excerpt'
    description = u'Adds filter for Markdown body excerpt.'

    def on_setup_env(self, **extra):
        def excerpt(value, separator='\n\n'):
            excerpt_source = value.source.split(separator)[0]

            return Markdown(excerpt_source)

        self.env.jinja_env.filters['excerpt'] = excerpt



from setuptools import setup

setup(
    name='lektor-markdown-excerpt',
    description='Adds filter for Markdown body excerpt.',
    author='Luka Zakrajsek',
    author_email='luka@bancek.net',
    url='http://github.com/bancek/lektor-markdown-excerpt',
    version='0.1',
    license='BSD',
    py_modules=['lektor_markdown_excerpt'],
    entry_points={
        'lektor.plugins': [
            'markdown-excerpt = lektor_markdown_excerpt:MarkdownExcerptPlugin',
        ]
    }
)
